Type: Package
Package: admiralvaccine
Title: Vaccine Extension Package for ADaM in 'R' Asset Library
Version: 0.6.0
Authors@R: c(
    person("Arjun", "Rubalingam", , "arjun.rubalingam@pfizer.com", role = c("aut", "cre")),
    person("Sukalpo", "Saha", , "sukalpo.saha@pfizer.com", role = c("aut", "ctb")),
    person("Ben", "Straub", , "ben.x.straub@gsk.com", role = "aut"),
    person("Vikram", "S", role = "aut"),
    person("Dhivya", "Kanagaraj", role = "aut"),
    person("Federico", "Baratin", role = "aut"),
    person("Yamini", "Purna Bollu", role = "aut"),
    person("Ilse", "Augustyns", role = "aut"),
    person("Kalyani", "Bodicherla", role = "aut"),
    person("Hilde", "Delanghe", role = "aut"),
    person("Lee", "Armishaw", role = "aut"),
    person("Neetu", "Sangari", role = "ctb"),
    person("Abdul", "Khayat", role = "ctb"),
    person("Ankur", "Jindal", role = "ctb"),
    person("Jayashree", "V", role = "ctb"),
    person("Jagadish", "Katam", role = "ctb"),
    person("Andrea", "Pammolli", role = "ctb"),
    person("Daniele", "Bottigliengo", role = "ctb"),
    person("Ranya", "Ben Hsain", role = "ctb"),
    person("Marleen", "Nijs", role = "ctb"),
    person("Mandy", "Peng", role = "ctb"),
    person("Tina", "Zhai", role = "ctb"),
    person("Ross", "Farrugia", role = "ctb"),
    person("Stefan", "Bundfuss", role = "ctb"),
    person("Edoardo", "Mancini", role = "ctb"),
    person("Pfizer Inc.", role = c("cph", "fnd")),
    person("GlaxoSmithKline LLC", role = c("cph", "fnd")),
    person("Johnson & Johnson", role = c("cph", "fnd"))
  )
Description: Programming vaccine specific Clinical Data Interchange
    Standards Consortium (CDISC) compliant Analysis Data Model (ADaM)
    datasets in 'R'. Flat model is followed as per Center for Biologics
    Evaluation and Research (CBER) guidelines for creating vaccine
    specific domains. ADaM datasets are a mandatory part of any New Drug
    or Biologics License Application submitted to the United States Food
    and Drug Administration (FDA). Analysis derivations are implemented in
    accordance with the "Analysis Data Model Implementation Guide" (CDISC
    Analysis Data Model Team (2021),
    <https://www.cdisc.org/standards/foundational/adam/adamig-v1-3-release-package>).
    The package is an extension package of the 'admiral' package.
License: Apache License (>= 2)
URL: https://pharmaverse.github.io/admiralvaccine/,
        https://github.com/pharmaverse/admiralvaccine/
BugReports: https://github.com/pharmaverse/admiralvaccine/issues/
Depends: R (>= 3.5)
Imports: admiral (>= 1.4.0), admiraldev (>= 1.4.0), assertthat (>=
        0.2.1), cli (>= 3.6.2), dplyr (>= 0.8.4), hms (>= 0.5.3),
        lifecycle (>= 0.1.0), lubridate (>= 1.7.4), magrittr (>= 1.5),
        purrr (>= 0.3.3), rlang (>= 0.4.4), stringr (>= 1.4.0), tidyr
        (>= 1.0.2), tidyselect (>= 1.0.0)
Suggests: covr, devtools, diffdf, DT, knitr, lintr, metatools, methods,
        miniUI, pharmaversesdtm, pkgdown, rmarkdown, roxygen2,
        spelling, testthat, tibble, usethis
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-01-23 16:10:13 UTC; Arjun
Author: Arjun Rubalingam [aut, cre],
  Sukalpo Saha [aut, ctb],
  Ben Straub [aut],
  Vikram S [aut],
  Dhivya Kanagaraj [aut],
  Federico Baratin [aut],
  Yamini Purna Bollu [aut],
  Ilse Augustyns [aut],
  Kalyani Bodicherla [aut],
  Hilde Delanghe [aut],
  Lee Armishaw [aut],
  Neetu Sangari [ctb],
  Abdul Khayat [ctb],
  Ankur Jindal [ctb],
  Jayashree V [ctb],
  Jagadish Katam [ctb],
  Andrea Pammolli [ctb],
  Daniele Bottigliengo [ctb],
  Ranya Ben Hsain [ctb],
  Marleen Nijs [ctb],
  Mandy Peng [ctb],
  Tina Zhai [ctb],
  Ross Farrugia [ctb],
  Stefan Bundfuss [ctb],
  Edoardo Mancini [ctb],
  Pfizer Inc. [cph, fnd],
  GlaxoSmithKline LLC [cph, fnd],
  Johnson & Johnson [cph, fnd]
Maintainer: Arjun Rubalingam <arjun.rubalingam@pfizer.com>
Repository: CRAN
Date/Publication: 2026-01-23 16:30:02 UTC
Built: R 4.6.0; ; 2026-04-30 06:42:31 UTC; unix
